﻿<#
    .Synopsis
    Funksjonen formaterer en liste med XmlElement-enheter fra Airwave, til et array med objekter som har attributtene til enhetene

    .Description
    Funksjonen går gjennom dataen fra listen med XmlElement-enheter, henter informasjonen til hver enhet, og legger attributtene inn i et objekt. Objektene blir så lagt inn i et array, som outputtes til pipeline.
    Attributtene som blir lagt inn blir gitt prefixen AMP_

    .Parameter AMPData
    Object[XmlElement], array av XmlElementer. I de fleste tilfeller er dette outputten fra $apmRawData.report.pickled_user_inventory. ampRawData er outputten fra Get-AMPClients 

    .Notes
    Funksjonen er designet for å fungere med outputten fra Get-AMPData. Get-AMPData sin report.pickled_user_inventory vil fungere som input til funksjonen.

    .Example
    PS>$ampRawData = Get-AMPClients -uName "apibruker1" -pWord "Password1!" -airWaveHost "https://airwaveserver.domene.local:443" -reportID 2332
    PS>$ampUsefulData = $ampRawData.report.pickled_user_inventory
    PS>$ampFormatertData = Format-AMPData -AMPData $apmUsefulData
    Henter rapporten, henter pickled_user_inventory, og formaterer dataen til variabel.

#>
Function Format-AMPClients{
    
    [CmdletBinding()]
    param(
        [Parameter(Mandatory=$true)][Object[]]$AMPData
    )

    Write-Verbose "Kjører Format-AMPEnpoints"

    Write-Verbose "Initialiserer array og setter propertyprefix"
    $formatertData = @()
    $propertyPrefix = "AMP_"
    [DateTime]$now = [DateTime]::Now

    $i = 0
    $count = $AMPData.count

    $IP_ARRAY = @{}
    $IP_ARRAY = Format-IPtable -path ($PSScriptRoot + '\..\DHCP scopes, Domstoladministrasjonen.xlsx')

    Write-Verbose "Starter løkke for gjennomgang av inndata"
    ForEach($enhet in $AMPData){
        $tempObject = New-Object PSCustomObject
        $mac = $enhet.mac
        Write-Verbose "`tStarter gjennomgang for enhet $mac"

        $connect_time = ConvertFrom-UnixTime $enhet.connect_time

        Write-Debug "`t`t`tLegger til property connect_time = $Connect_Time"
        $tempObject | Add-Member -NotePropertyName $PropertyPrefix"Connect_Time" -NotePropertyValue $connect_time
        
        $lan_ips = $enhet.lan_ips
        Write-Debug "`t`t`tLegger til property lan_ips = $lan_ips"
        $tempObject | Add-Member -NotePropertyName $propertyPrefix"Lan_IPs" -NotePropertyValue $enhet.lan_ips

        $IPlok = @()

        Write-Verbose "Sjekker lokasjon for ip-adresse"
        foreach ($ip in $lan_ips) {
            $ipcomp = Format-IPLok $ip

            Write-Debug "Sjekker lokasjon for $ip"

            if($IP_ARRAY.containskey($ipcomp)){
                $IPlok += $IP_ARRAY.$ipcomp
                $DebugLok = $IP_ARRAY.$ipcomp
                Write-Debug "$ip tilhorer $DebugLok"

            }
            else{
                if($ip -like "*::*:*:*:*"){
                    $IPlok += "Unknown Local IPv6"
                    Write-Debug "$ip er en Unknown Local IPv6"
                }elseif ($ip -like "*.*.*.*") {
                    $IPlok += "Unknown IPv4"
                    Write-Debug "$ip er en Unknown IPv4"
                }elseif ($ip -like "????:????:*"){
                    $IPlok += "Unknown Public IPv6"
                    Write-Debug "$ip er en Unknown Public IPv6"
                }
            }
            
        }
        $tempobject | Add-Member -MemberType NoteProperty -Name AMP_LAN_IPLOK -Value $IPLok

        $lan_hostnames = $enhet.lan_hostnames
        Write-Debug "`t`t`tLegger til property lan_hostnames = $lan_hostnames"
        $tempObject | Add-Member -NotePropertyName $propertyPrefix"Lan_Hostnames" -NotePropertyValue $enhet.lan_hostnames

        ForEach($property in $enhet.Attributes.name){
            If(-not($property -eq "connect_time")){
                $propName = (Get-Culture).TextInfo.ToTitleCase($property)
                $tempObject | Add-Member -NotePropertyName $propertyPrefix$propName -NotePropertyValue ($enhet.$property)
                $propVal = $enhet.$property
                Write-Debug "`t`t`tLegger til property $property = $propVal"
            }#End If
        }#End ForEach

        $tempObject | Add-Member -NotePropertyName $propertyPrefix"Dato" -NotePropertyValue $now

        Write-Verbose "`tSender enhet $mac til formatertData"
        $formatertData += $tempObject
        $i++
        Write-Progress -Activity "Formaterer data..." -Status "Formatert: $i av $count" -PercentComplete (($i / $count) * 100)
    }#End ForEach

    Write-Verbose "Returnerer formatertData`n"
    $formatertData
}#End Function