﻿<#
    .Synopsis
    Funksjonen henter siste rapport av spesifisert rapporttype fra en Airwave-server, gjennom APIet

    .Description
    Funksjonen kobler seg til innloggingsAPIet til en Airwave-server med brukernavn og passord, og bruker websessionen for å hente ut siste rapport av spesifisert rapporttype

    .Parameter uName
    Spesifiserer brukernavnet til API-brukeren på serveren

    .Parameter pWord
    Spesifiserer passordet til API-brukeren i klartekst

    .Parameter airWaveHost
    Spesifiserer URL til airwaveserveren

    .Parameter reportId
    Spesifiserer ID til rapporten på Airwave-serveren. Denne finner du ved å edite rapporten i Airwave, og se på URLen. På slutten av URL vil det stå "id=xxx"
    
    .Notes
    Funksjonen returnerer en XML-fil. I bruksområdet funksjonen er laget til vil den returnere en XML-fil med property "pickled_user_inventory". Bruk "pickled_user_inventory" i Format-AMPData

    .Example
    PS>Get-AMPClients -uName "apibruker1" -pWord "Password1!" -airWaveHost "https://airwaveserver.domene.local:443" -reportID 2332
    Henter rapporten og outputter den til pipeline

    .Example
    PS>$ampRawData = Get-AMPClients -uName "apibruker1" -pWord "Password1!" -airWaveHost "https://airwaveserver.domene.local:443" -reportID 2332
    PS>$ampUsefulData = $ampRawData.report.pickled_user_inventory
    PS>$ampFormatertData = Format-AMPData -AMPData $apmUsefulData
    Henter rapporten, henter pickled_user_inventory, og formaterer dataen til variabel.

#>
function Get-AMPClients{

[CmdletBinding()]
param(
    [Parameter(Mandatory)][string]$uName,
    [Parameter(Mandatory)][string]$pWord,
    [Parameter(Mandatory)][string]$airWaveHost,
    [Parameter(Mandatory)][int]$reportID
)

    Write-Verbose "Formaterer URL og request body."

    $loginURL = $airWaveHost + "/LOGIN"
    Write-Debug "loginURL = $loginURL"

    $body = "credential_0=" + $uName + "&credential_1=" + $pWord + "&destination=/index.html"
    Write-Debug "request body = $body"


    Write-Verbose "Logger inn på API og lagrer websession"
    $loginObj = Invoke-RestMethod -Uri $loginURL -Method Post -Body $body -ContentType "application/x-www-form-urlencoded;charset=UTF-8" -SessionVariable session

    Write-Verbose "Henter rapport fra API"
    $reqURL = "https://"+$airWaveHost+"/latest_report.xml?id="+$reportID
    Invoke-RestMethod -Uri $reqURL -WebSession $session
}#End Function