<#
    .SYNOPSIS
    Scriptet benytter nodedata som er lagret i mellomlageret fra "hent utdata.ps1" og analyserer den, og sender resultatet av analysen databasen.

    .DESCRIPTION
    Scriptet henter først nødvendige funksjoner fra \universalt og \analyse, og parser deretter konfigurasjonsfilen. SCriptet henter så ut alle sett med nodedata som ligger i mellomlageret, og konsoliderer disse per enhet, og hver analyse kjøres for hver enhet, og resultatet blir deretter sendt til databasen.

#>


###################--Dot source av nødvendige funksjoner--###################

$dirs = Get-ChildItem -Path $PSScriptRoot | Where-Object -Property mode -EQ -Value d-----
foreach ($dir in $dirs){
    Get-ChildItem -Path $dir.FullName -Filter *.ps1 | ForEach-Object {. $_.FullName}
}
###################--Parsing av configfil--###################

try {
    $config = Get-ConfigFil -pathTilFil $PSScriptRoot/configuration.ini
}
catch {
    throw "Klarte ikke parse configfil. Sjekk at filen `$PSScriptRoot/configuration.ini finnes, og at den er riktig formatert"

}

$rootPath = $PSScriptRoot

#Universal
$pathTilMellomLager = ""
if($config.RelPaths -eq $true){
    $pathTilMellomLager = $rootPath + $config.pathTilMellomLager
}else{
    $pathTilMellomLager = $config.pathTilMellomLager
}

$pathTilAnalyser = ""
if($config.RelPaths -eq $true){
    $pathTilAnalyser = $rootPath + $config.pathTilAnalyser
}else{
    $pathTilAnalyser = $config.pathTilAnalyser
}
$SecretMode = $config.SecretMode

#Azure
$AzureUserName = $config.Azure_UserName
$AzureSQLServer = $config.Azure_SQLServer
$AzurePort = $config.Azure_Port
$AzureDatabaseNavn = $config.Azure_databaseNavn

$Azurepassword = ""
if ($secretMode -eq "plain") {
    $Azurepassword = $config.Azure_password
}elseif ($SecretMode -eq "file") {
    $Azurepassword = Get-Content $config.Azure_passwordPath | Unprotect-Passord
}

#SQL
$SQLBatchSize = $config.SQL_BatchSize

if($SQLBatchSize -gt 1000){
    $SQLBatchSize = 1000
}elseif($SQLBatchSize -lt 1){
    $SQLBatchSize = 1
}

############--Samle data og analyser--######################

$historiskData = Get-HistoriskData -pathTilUthentinger $pathTilMellomLager

$mergedData = Merge-HistoriskData -historiskNodeData $historiskData

$analyseListe = Get-AnalyseListe -path $pathTilAnalyser

$analyseResult = Test-EnhetsTabell -enhetsTabell $mergedData -funksjoner $analyseListe

if ($analyseResult.count -gt 0) {
    $formatertAnalyseResult = Format-AnalyseResultat -analyseResultater $analyseResult
} else {
    Write-verbose "Ingen trusler funnet"
}

##############--Send resultater til database--###################

if ($analyseResult.count -gt 0 ){
    Write-verbose "Minimum en trussel funnet i analyser. Sender data til database"

    Write-verbose "Tester SQL-connection"
    $isSQL = Test-SqlConnection -brukernavn $AzureUserName -passord $Azurepassword -SQLServer $AzureSQLServer -port $AzurePort -DatabaseNavn $AzureDatabaseNavn
    
    if ($isSQL) {
        Write-Debug "Connection til database OK"

        Write-verbose "Batcher analyseresultater"
        $batchedResults = Group-SQLInnsending -udeltTing $formatertAnalyseResult -batchSize $SQLBatchSize

        Write-Debug "Starter ForEach enhetBatch in bacthedEnheter"
        foreach ($analyseBatch in $batchedResults) {
            $analyseQuery = New-SqlQueryEnheterTrusler -AnalyserteEnheter $analyseBatch
            Write-Debug "Query som sendes til database: `n$analyseQuery"

            Write-Debug "Prover aa sende query til tabell Enheter_Trusler i database"
            try {
                Send-QueryToDatabase -Query $analyseQuery -brukernavn $AzureUserName -passord $Azurepassword -SQLServer $AzureSQLServer -port $AzurePort -DatabaseNavn $AzureDatabaseNavn
            }
            catch {
                $ErrorMessage = $_.Exception.Message
                Write-Host "Feil i innsending til tabell Enheter_Trusler i database" -ForegroundColor Red
                Write-Host $ErrorMessage -ForegroundColor Red
            }
        }
    } else {
        Write-Host "Klarte ikke koble til Azure-SQL server. Se [Azure Database] i konfigfil" -ForegroundColor Red
    }

} else {
    Write-Verbose "Ingen trusler funnet, ingen data aa sende til database"
}