﻿<#
    .Synopsis
    Funksjonen analyserer de samlede uthentingene fra mellomlageret for en enhet, og returnerer dersom enheten ikke er funnet i SCCM

    .Description
    Funksjonen tar inn et objekt som består av alle uthentinger relatert til en mac-addresse, fra mellomlageret. Den går så gjennom hver uthenting, og dersom den finner
    en uthenting som tilhører SCCM, flagger den at enheten er administrert av SCCM. Dersom dette ikke skjer, blir ikke flagget satt, og analysen returnerer analysenavn,
    trussel-ID fra databasen (hardkodet) og true.

    .Parameter enhet
    En enhet med alle uthentinger, hentet fra mellomlageret. Innsendingen skal i all hovedsak foregå automatisk gjennom test-enhetstabell.

    .Notes
    For at denne funksjonen skal fungere alene, må man bruke Get-Historiskdata og Merge-Historiskdata, og velge en enhet fra den mergede historiske dataen, som man
    sender inn.
#>
Function Analyse_EnhetManglerIDomene{
    param(
        [Parameter(Mandatory)][object]$enhet
    )

    $analyseNavn = 1
    $resultat = $true

    #For hver dag det var uthenting for enheten, hent ut datoen for hver kilde
    $utdatoer = foreach($dagUthenting in $enhet){
        $daguthenting | Select-Object -Property CPPM_DATO, SCCM_DATO, AMP_DATO
    }

    #Dersom den finner en SCCM-dato, flagger den at enheten er administrert av SCCM.
    foreach ($dato in $utdatoer) {
        if ($null -eq $dato.sccm_dato) {
            Write-Debug "Fant ingen SCCM_dato for denne datoen"            
            Write-Debug $resultat
        }else{
            Write-Debug "Fant en SCCM_dato for denne datoen"
            $resultat = $false
            Write-Debug $resultat
        }
    }

    Write-Debug "`t`t`tAnalyse: $analysenavn ga svar $resultat"
    $out = ($analyseNavn, $resultat)
    Write-Debug $out[0]
    Write-Debug $out[1]
    $out
}