﻿Function Get-CPPMApiAccessToken {
<# 
    .Synopsis
    Funksjon for å hente API-Access-token fra Clearpass Policy manager

    .Description
    Funksjonen bruker URLen til Clearpass-serveren, API-klient-id og API-klient-secret for å få en access-token som kan brukes videre for å gjøre API-kall.

    .Parameter CPPMURL
    Spesifiserer URL til clearpass-serveren

    .Parameter clientId
    Spesifiserer ID til API-klienten man ønsker access-token fra

    .Parameter clientSecret
    Spesifiserer Secret-nøkkelen til API-klienten man ønsker access-token fra
    
    .Example
    PS>Get-CPPMApiAccessToken -CPPMURL "https://cppmserver.domain.local:443" -clientID "apiClient1" -clientSecret "HevfFpbkeRvd44dv3R6j21Dvvrzpf"

    Gir et objekt med attributtene type og access_token.

    .Example
    PS>$auth = Get-CPPMApiAccessToken -CPPMURL "https://cppmserver.domain.local:443" -clientID "apiClient1" -clientSecret "HevfFpbkeRvd44dv3R6j21Dvvrzpf"
    PS>$CPPMRawData = Get-CPPMEndPoints -bearerToken $auth -CPPMURL "https://cppmserver.domain.local:443"
    PS>$CCPMFormatertData = Format-CPPMEndpoints -CPPMData $CPPMRawData

    Henter access-token med Get-CPPMApiAccessToken, bruker denne for å hente endpoints med Get-CPPMEndPoints, og sender det videre til formateringsfunksjonen.
#>

    [CmdletBinding()]
    Param(
        [Parameter(Mandatory)][string]$CPPMURL,
        [Parameter(Mandatory)][string]$clientId,
        [Parameter(Mandatory)][string]$clientSecret
    )

#Formaterer bodyen til requesten med hvordan vi ønsker å få token, clientID og client-secret
$body = @"
{"grant_type": "client_credentials",
"client_id": "$clientId",
"client_secret": "$clientSecret"
}
"@

    #Formaterer URL for HTTP-request
    $reqURL = $CPPMURL + "/api/oauth"

    #Henter access-token
    $auth = Invoke-RestMethod -Method Post -Uri $reqURL -Body $body -ContentType application/json

    $token = $auth.access_token
    $token
}