<#
    .Synopsis
    Funksjonen brukes for å hente enheter fra CPPM, gjennom en XML-fil hentet fra Clearpass-GUI. Brukes ikke i nåværende versjon

    .Description
    Funksjonen går til den spesifiserte pathen, og henter XML-filen som ligger der. Deretter formaterer den informasjonen, og returnerer formatert data som kan brukes
    i de resterende funksjonen i scriptet, som merge-nodedata.
#>
function Get-CPPMEndpointsFromXML {
    [CmdletBinding()]
    param (
        [Parameter(Mandatory, ValueFromPipeline)][string]$pathTilData
    )

    [xml]$CPPMRaw = Get-Content $pathTilData

    $formatertData = @()
    $propertyPrefix = "CPPM_"

    ForEach ($endpoint in $CPPMRaw.TipsContents.Endpoints.Endpoint){
        $tempObj = New-Object PSCustomObject

        $macAddr = $endpoint.macAddress | Format-MAC
        $macVendor = $endpoint.macVendor

        $EProfile = $endpoint.EndpointProfile
        $EPAttr = $EProfile | Get-Member -MemberType Property | Select-Object -Property Name

        $tempObj | Add-Member -NotePropertyName $propertyPrefix"MAC" -NotePropertyValue $macAddr
        $tempObj | Add-Member -NotePropertyName $propertyPrefix"MAC_Vendor" -NotePropertyValue $macVendor

        ForEach ($attr in $EPAttr.Name){
            $propName = (Get-Culture).TextInfo.ToTitleCase($attr)
            $tempVal = $EProfile.$attr
            $tempObj | Add-Member -NotePropertyName $propertyPrefix$propName -NotePropertyValue $tempVal
        }
        
        $formatertData += $tempObj
    }

    $formatertData
}

