<#
    .Synopsis
    Funksjonen bruker historisk nodedata fra get-historiskdata, og merger den slik at hver mac-adresse er knyttet til alle uthentinger for den addressen.

    .Description
    Funksjonen benytter seg av den historiske dataen som er lagret i mellomlageret, sendt inn via get-historiskdata, og går gjennom hver uthenting, for å merge
    alle uthentinger som tilhører en MAC sammen. Resultatet blir en hashtable med Mac-addresser som keys, og alle uthentinger som er relevante som values, i et array.
#>
function Merge-HistoriskData {
    [CmdletBinding()]
    param (
        [Parameter(Mandatory, ValueFromPipeline)][object[]]$historiskNodeData
    )
    
    begin {
        $analyseTabell = @{}
    }
    
    process {
        foreach ($ukeUthenting in $historiskNodeData) {
            if ($analyseTabell.count -eq 0) {
                Write-Verbose "Analysetabell er tom, legger inn alle enheter i uthenting"
                foreach ($key in $ukeUthenting.keys) {
                    Write-Debug "`tLegger til MAC $key i analysetabell"
                    $analyseTabell.Add($key, $ukeUthenting.$key)
                }
            } else {
                Write-Verbose "Analysetabell er ikke tom, sjekker hver MAC"
                foreach ($key in $ukeUthenting.keys) {
                    if ($analyseTabell.ContainsKey($key)) {
                        Write-Verbose "MAC $key finnes i analysetabell, legger data til vedsidenav"
                        $Value = @()
                        $value += $analyseTabell.$key
                        $value += $ukeUthenting.$key
                        $analyseTabell.$key = ($value)
                    }else{
                        Write-Verbose "MAC $key finnes ikke i analysetabell, legger til ny"
                        $analyseTabell.add($key, $ukeuthenting.$key)
                    }
                }
            }
        }
    }
    
    end {
        $analyseTabell
    }
}