﻿<#
    .synopsis
    Funksjonen merger nodedata fra uthentingene som blir sendt inn, slik at hver mac har alle relevante uthentinger på seg for mellomlagring og analyse.

    .Description
    Funksjonen får inn ett array med nodedata, som består av de uthetningene som er hentet. Funksjonen finner så en identifiserende verdi i nodedatacollectionsene,
    som SCCM_MAC eller CPPM_MAC. Om den ikke finner en identifikator settes den til DATA[n]. Deretter går den gjennom hver collection, og finner enheter med lik MAC,
    og legger de inn i en enhetstabell som består av all hentet informasjon samlet.
#>

Function Merge-NodeData{
    [CmdletBinding()]
    param([hashtable]$enhetsTabell=@{}, [object[]]$nodeData)

    $nodeDataCollection = Clone-Object $nodeData

    Write-Verbose "Starter Merge-NodeData"
    $counter = 1
    $outerCount = $nodeDataCollection.Count

    ForEach($collection in $nodeDataCollection){
        Write-Verbose "Starter merging av datakilde $counter"
        
        #Legg inn nye identifiserende datakilder her.
        
        Write-Verbose "`tIdentifiserer datakilde"
        $dataIdentifier = $collection[0].psobject.Properties.name[0].Split("_")[0]

        Write-Verbose "`tSetter identifiserende verdi for enheter basert på datakilden"
        $collectionIdentifier = ""
        if($dataIdentifier -eq "SCCM"){
            $collectionIdentifier = "SCCM_MAC"

            Write-Debug "`t`t`tIdentifiserte datakilde SCCM. Setter collectionIdentifier til $collectionIdentifier"
        }elseif($dataIdentifier -eq "AMP"){
            $collectionIdentifier = "AMP_mac"

            Write-Debug "`t`t`tIdentifiserte datakilde som AMP. Setter collectionIdentifier til $collectionIdentifier"
        }elseif($dataIdentifier -eq "CPPM"){
            $collectionIdentifier = "CPPM_MAC"

            Write-Debug "`t`t`tIdentifiserte datakilde som CPPM. Setter collectionIdentifier til $collectionIdentifier"
        }else{
            $collectionIdentifier = "mac"
            $dataIdentifier = "DATA"+$counter

            Write-Debug "`t`t`tKlarte ikke identifisere datakilde. Setter collectionIdentifier til $collectionIdentifier, og dataIdentifier til $dataIdentifier"
        }#End If dataidentifier

        If($enhetsTabell.Count -gt 0){

            Write-Verbose "`tEnhetstabell er ikke tom, kjører sjekk for hver enhet"
            $innerCount = $collection.count
            $innerCounter = 1
            ForEach($enhet in $collection){

                $mac = $enhet.$collectionIdentifier
                if($mac -like "??:??:??:??:??:??"){

                    Write-Verbose "MAC-adresse $mac funnet"
                    if($enhetsTabell.ContainsKey($mac)){

                        Write-Verbose "`t`tEnhet $mac finnes i enhetstabell. Legger til properties til eksisterende enhet"
                        ForEach($property in $enhet.psobject.Properties.name){

                            $propVal = $enhet.$property
                            Write-Debug "`t`t`t`tLegger til property $property = $propVal"

                            If($dataIdentifier -like "DATA?"){

                                Write-Debug "`t`t`t`t`tDatakilden er uvisst, formaterer data som legges inn i enhetstabell med prefix $propertyName"
                                $propertyName = $dataIdentifier+"_"+$property
                                $enhetsTabell."$mac" | Add-Member -NotePropertyName $propertyName -NotePropertyValue $enhet.$property

                            }else{

                                $enhetsTabell."$mac" | Add-Member -NotePropertyName $property -NotePropertyValue $enhet.$property

                            }#End if

                        }#End ForEach property in klient-object

                    }else{

                        Write-Verbose "`t`tEnhet $mac finnes ikke i enhetsTabell. Legger til ny enhet"
                        if($dataIdentifier -like "DATA?"){
                            $tempEnhet = New-Object PSCustomObject
                            ForEach($property in $enhet.psobject.Properties.name){
                                Write-Debug "`t`t`t`t`tDatakilden er uvisst, formaterer data som legges inn i enhetstabell med prefix $propertyName"
                                $propertyName = $dataIdentifier+"_"+$property
                                $tempEnhet | Add-Member -NotePropertyName $propertyName -NotePropertyValue $enhet.$property
                            }
                            $enhetsTabell.Add($mac, $tempEnhet)
                        }else{
                            $enhetsTabell.Add($mac, $enhet)
                        }
                    }#End If enhetstabell contains MAC
                }else{

                    Write-Verbose "`t`tFant ingen identifiserende MAC for enhet. Går til neste enhet"
                }#End If $mac -ne ""
            Write-Progress -Activity "Legger inn enheter..." -Status "lagt inn: $innerCounter av $innerCount" -PercentComplete (($innerCounter / $innerCount) * 100) -ParentId 1
            $innerCounter++
            }#End ForEach enhet in collection
        }else{

            Write-Verbose "`tEnhetstabell er tom. Legger inn alle enheter"
            $innerCount = $collection.count
            $innerCounter = 1
            ForEach($enhet in $collection){
                $mac = $enhet.$collectionIdentifier
                if($mac -like "??:??:??:??:??:??"){
                    if($dataIdentifier -like "DATA?"){
                        $tempEnhet = New-Object PSCustomObject
                        ForEach($property in $enhet.psobject.Properties.name){
                            Write-Debug "`t`t`t`t`tDatakilden er uvisst, formaterer data som legges inn i enhetstabell med prefix $propertyName"
                            $propertyName = $dataIdentifier+"_"+$property
                            $tempEnhet | Add-Member -NotePropertyName $propertyName -NotePropertyValue $enhet.$property
                        }
                        $enhetsTabell.Add($mac, $tempEnhet)
                    }else{
                        $enhetsTabell.Add($mac, $enhet)
                    }
                }else{

                    Write-Verbose "`t`tFant ingen identifiserende MAC for enhet. Går til neste enhet"
                }#End If $mac -ne ""
            Write-Progress -Activity "Legger inn enheter..." -Status "lagt inn: $innerCounter av $innerCount" -PercentComplete (($innerCounter / $innerCount) * 100) -ParentId 1
            $innerCounter++
            }#End ForEach enhet in collection
        }#End If enhetsTabell.count
        Write-Verbose "Ferdig med datakilde $counter`n"
        Write-Progress -Activity "Merger enhetstabell..." -Status "Datakilde: $counter av $outerCount" -PercentComplete (($counter / $outerCount) * 100) -Id 1
        $counter ++
    }#End ForEach object in nodeDataCollection

    $count = $enhetsTabell.count
    Write-Verbose "Returnerer enhetsTabell med $count enheter`n"
    $enhetsTabell
}#End Function
