﻿<#
    .synopsis
    Funksjonen tar inn en enhetstabell fra merge-historiskdata, og en liste med analyser fra get-analyseliste. Deretter utfører funksjonen alle analyser funnet på alle
    enheter i enhetstabellen.

    .description
    Funksjonen bruker enhetstabellen fra merge-historiskdata, og analysene fra get-analyseliste, for å analysere all informasjon hentet. Funksjonen går gjennom hver
    mac-addresse i enhetstabellen, og utfører deretter alle analysene på hver enhet. Dersom analysen returnerer et resultat (som alltid vil være analysenavn, 
    analyse-id og true), legger den dette inn i resultatene som returneres. Resultatene sendes inn til format-analyseresultat.
#>

Function Test-EnhetsTabell {
    [CmdletBinding()]
    param(
        [Parameter(Mandatory)][hashtable]$enhetsTabell,
        [Parameter(Mandatory)][string[]]$funksjoner
    )

    $analyseResultater = @()
    $outerCounter = 1
    $outerCount = $enhetsTabell.Count
    $propPrefix = "Analyse_"

    ForEach($key in $enhetsTabell.Keys){
        $enhetMAC = $key
        Write-Verbose "Starter tester mot enhet $enhetMac"

        $innerCounter = 1
        $innerCount = $funksjoner.Count
        ForEach($funksjon in $funksjoner){

            Write-Debug "`tKjører test på enhet $enhetMac"
            $testResult = & $Funksjon -enhet $enhetsTabell."$enhetMAC"
            $testName = $testResult[0]
            $testValue = $testResult[1]
            If($testResult[1] -eq $true){
                Write-Debug "`t`tLegger inn property $testName = $testValue til enhet"
                $analyseResultater += ,($enhetMAC, $testName, $testValue)
            }else{
                Write-Debug "`t`tTest fant ikke en trussel, legger ikke inn resultat til enhet"
            }#/If
            Write-Debug "`tFerdig test $testName på enhet $enhetMac"

            Write-Progress -Activity "Kjører analyser mot enhet..." -Status "Analyse nummer: $innerCounter av $innerCount" -PercentComplete (($innerCounter / $innerCount) * 100) -ParentId 1
            $innerCounter++
        }#/ForEach funksjon in funksjoner

        Write-Debug "Ferdig tester mot enhet $enhetMac`n"
        Write-Progress -Activity "Analyserer enhetstabell..." -Status "Analysert: $outerCounter av $outerCount" -PercentComplete (($outerCounter / $outerCount) * 100) -Id 1
        $OuterCounter++
    }#/ForEach enhet in enhetstabell

    Write-Verbose "Returnerer Enhetstabell`n"
    $analyseResultater
}#/Function
