﻿Function New-AMPFakeData{
    [CmdletBinding()]
    param(
        [Parameter()][int]$count, 
        [Parameter(Mandatory)][hashtable]$macs,
        [Parameter()][DateTime]$now = [DateTime]::Now        
    )

    $localMacs = $macs.Clone()
    $enheter = @()
    $apDetails = (
        @{
            ap_name = "NORD-01-01";
            ap_id = 1;
            ap_radio_description = "802.11bgn"
        },
        @{
            ap_name = "NORD-02-03";
            ap_id = 2;
            ap_radio_description = "802.11ac"
        },
        @{
            ap_name = "SOR-01-01";
            ap_id = 3;
            ap_radio_description = "802.11bgn"
        },
        @{
            ap_name = "VEST-01-01";
            ap_id = 4;
            ap_radio_description = "802.11bgn"
        }
    )
    $deviceDetails = (
        @{
            aruba_device_type = "Win 10";
            device_os = "Windows";
            device_os_detail = "Windows NT 10.0; Win64; x64"
            device_type = "Windows 10"
        },
        @{
            aruba_device_type = "Win 7";
            device_os = "Windows";
            device_os_detail = "Windows NT 6.1; Win64; x64; rv:65.0"
            device_type = "Windows 7"
        },
        @{
            aruba_device_type = "";
            device_os = "";
            device_os_detail = ""
            device_type = "Apple, Inc."
        },
        @{
            aruba_device_type = "Win 8";
            device_os = "Windows";
            device_os_detail = "Windows NT 6.3; Win64; x64"
            device_type = "Windows 8"
        }
    
    )
    $networkVendors = (
        "Intel Corprate",
        "Hon Hai Precision Ind. Co.,Ltd.",
        "Apple, Inc.",
        "SAMSUNG ELECTOR-MECHANICS (THAILAND)"
    )
    $networkIds = (
        "Domstol gjestenett",
        "Domstol internnett",
        "Domstol internnett",
        "Domstol internnett"
    )
    $htModes = (
        "20",
        "40",
        "120"
    )
    
    For($i = 1; $i -le $count; $i++){
        $tempObject = New-Object PSCustomObject

        $connecttime = New-RandomDate -max $now.AddDays(-1)
        $mac = $localMacs.Keys | Get-Random
        
        $apDetail = Get-Random $apDetails
        $deviceDetail = Get-Random $deviceDetails
        $networkVendor = Get-Random $networkVendors
        $networkId = Get-Random $networkIds
        $fullIP = ""
        $iplok = ""
        $useProperIP = Get-Random -Minimum 0 -Maximum 8
        if($useProperIP -eq 0){
            $fullIP = New-RandomIP
            $iplok = "Unknown IPv4"
        }else{
            $ip = $localMacs."$mac"[0]
            $ipSuff = Get-Random -Minimum 10 -Maximum 250
            $fullIP = $ip + $ipSuff
            $iplok = $localMacs."$mac"[1]
        }
        $duration = Get-Random -Minimum 500 -Maximum 20000
        $htMode = Get-Random $htModes
        
        $tempObject | Add-Member -NotePropertyName "AMP_connect_time" -NotePropertyValue $connecttime
        $tempObject | Add-Member -NotePropertyName "AMP_lan_ips" -NotePropertyValue $fullIP
        $tempObject | Add-Member -NotePropertyName "AMP_IPLok" -NotePropertyValue $iplok
        $tempObject | Add-Member -NotePropertyName "AMP_lan_hostnames" -NotePropertyValue ""
        $tempObject | Add-Member -NotePropertyName "AMP_ap_id" -NotePropertyValue $apDetail.ap_id
        $tempObject | Add-Member -NotePropertyName "AMP_ap_name" -NotePropertyValue $apDetail.ap_name
        $tempObject | Add-Member -NotePropertyName "AMP_ap_radio_description" -NotePropertyValue $apDetail.ap_radio_description
        $tempObject | Add-Member -NotePropertyName "AMP_aruba_device_type" -NotePropertyValue $deviceDetail.aruba_device_type
        $tempObject | Add-Member -NotePropertyName "AMP_asset_category" -NotePropertyValue ""
        $tempObject | Add-Member -NotePropertyName "AMP_asset_group" -NotePropertyValue ""
        $tempObject | Add-Member -NotePropertyName "AMP_device_manufacturer" -NotePropertyValue ""
        $tempObject | Add-Member -NotePropertyName "AMP_device_model" -NotePropertyValue ""
        $tempObject | Add-Member -NotePropertyName "AMP_device_os" -NotePropertyValue $deviceDetail.device_os
        $tempObject | Add-Member -NotePropertyName "AMP_device_os_detail" -NotePropertyValue $deviceDetail.device_os_detail
        $tempObject | Add-Member -NotePropertyName "AMP_device-type" -NotePropertyValue $deviceDetail.device_type
        $tempObject | Add-Member -NotePropertyName "AMP_duration" -NotePropertyValue $duration
        $tempObject | Add-Member -NotePropertyName "AMP_eap_supplicant" -NotePropertyValue ""
        $tempObject | Add-Member -NotePropertyName "AMP_forward_mode" -NotePropertyValue "0"
        $tempObject | Add-Member -NotePropertyName "AMP_ht_mode" -NotePropertyValue $htMode
        $tempObject | Add-Member -NotePropertyName "AMP_is_guest_user" -NotePropertyValue "0"
        $tempObject | Add-Member -NotePropertyName "AMP_mac" -NotePropertyValue $mac.ToUpper()
        $tempObject | Add-Member -NotePropertyName "AMP_network_chipset" -NotePropertyValue ""
        $tempObject | Add-Member -NotePropertyName "AMP_network_driver" -NotePropertyValue ""
        $tempObject | Add-Member -NotePropertyName "AMP_network_vendor" -NotePropertyValue $networkVendor
        $tempObject | Add-Member -NotePropertyName "AMP_radio_mode" -NotePropertyValue "n"
        $tempObject | Add-Member -NotePropertyName "AMP_report_id" -NotePropertyValue "293"
        $tempObject | Add-Member -NotePropertyName "AMP_role" -NotePropertyValue "cp-gjest"
        $tempObject | Add-Member -NotePropertyName "AMP_snmp_trap_source" -NotePropertyValue "0"
        $tempObject | Add-Member -NotePropertyName "AMP_ssid" -NotePropertyValue $networkId
        $tempObject | Add-Member -NotePropertyName "AMP_username" -NotePropertyValue $mac
        $tempObject | Add-Member -NotePropertyName "AMP_visualrf_location" -NotePropertyValue "-"
        $tempObject | Add-Member -NotePropertyName "AMP_vlan" -NotePropertyValue "27"
        $tempObject | Add-Member -NotePropertyName "AMP_dato" -NotePropertyValue $now

        $enheter += $tempObject

        $localMacs.Remove($mac)

        Write-Progress -Activity "Lager AMP-enheter..." -Status "Utført: $i av $count" -PercentComplete (($i / $count) * 100)
    }
    $enheter
}
