﻿Function New-SCCMFakeData{
    [CmdletBinding()]
    param(
        [Parameter()][int]$count, 
        [Parameter(Mandatory)][hashtable]$macs,
        [Parameter()][DateTime]$now = [DateTime]::Now,
        [Parameter()][object]$disAllowed
    )


    $localMacs = $macs.Clone()
    $enheter = @()

    $osVersions = (
        "Windows 7",
        "Windows 10",
        "Windows 8",
        "Windows Server 2016/2019"
    )
    $clientVersions = (
        "5.00.8634.1010",
        "5.00.8740.1003",
        "5.00.8355.1307"
    )
    $users = (
        "administrator",
        "olanor@domstoladministrasjon.no",
        "karinor@domstoladministrasjon.no",
        "heidistat@domstoladministrasjon.no",
        "itman@domstoladministrasjon.no"
    )


    For($i = 1; $i -le $count; $i++){
        $tempObject = New-Object PSCustomObject

        $mac = ""
        $ips = @()
        $iploks = @()
        $comName = ""

        $selectedMac = $localMacs.Keys | Get-Random

        $isDisallowed = $false
        foreach($disIP in $disAllowed){
            if($disIP -eq $selectedMac){
                $isDisallowed = $true
            }
        }

        if($isDisallowed){
            continue
        }
        
        $useProperMac = Get-Random -Minimum 0 -Maximum 20
        if($useProperMac -eq 0){
            $mac = New-RandomMac
            $ip = New-RandomIP
            $ips += $ip
            $iploks += "Unknown IPv4"
            $comName = New-RandomString -length 8
        }else{
            $mac = $selectedMac
            $ip = $localMacs."$mac"[0]
            $ipSuff = Get-Random -Minimum 10 -Maximum 250
            $fullIP = $ip += $ipSuff
            $ips += $fullip
            $iplok = $localMacs."$Mac"[1]
            $iploks += $iplok
            $comName = $iplok + "_" +$i
        }
        
        $computerName = $comName + ".domstol.no"
        $runspaceID = New-RandomString -length 40
        $resourceID = ($i + 16777220)
        $sms = "SMS_R_System.ResourceId=" + $resourceID
        $user = Get-Random $users
        $sid = "S-1-5-21-3051587635-922086871-3517838963-"+$i
        $lastLogon = New-RandomDate -max $now.addDays(-1)
        $clientVersion = Get-Random $clientVersions
        $osVersion = Get-Random $osVersions


        $tempObject | Add-Member -NotePropertyName "SCCM_PSComputerName" -NotePropertyValue $computerName
        $tempObject | Add-Member -NotePropertyName "SCCM_RunspaceId" -NotePropertyValue $runspaceID
        $tempObject | Add-Member -NotePropertyName "SCCM_MAC" -NotePropertyValue $mac.ToUpper()
        $tempObject | Add-Member -NotePropertyName "SCCM_IPAddresses" -NotePropertyValue $ips
        $tempObject | Add-Member -NotePropertyName "SCCM_IPLok" -NotePropertyValue $iploks
        $tempObject | Add-Member -NotePropertyName "SCCM_SmsProviderObjectPath" -NotePropertyValue $sms
        $tempObject | Add-Member -NotePropertyName "SCCM_ClientVersion" -NotePropertyValue $clientVersion
        $tempObject | Add-Member -NotePropertyName "SCCM_LastLogonTimestamp" -NotePropertyValue $lastLogon
        $tempObject | Add-Member -NotePropertyName "SCCM_LastLogonUserName" -NotePropertyValue $user
        $tempObject | Add-Member -NotePropertyName "SCCM_Name" -NotePropertyValue $comName
        $tempObject | Add-Member -NotePropertyName "SCCM_OperatingSystemNameandVersion" -NotePropertyValue $osVersion
        $tempObject | Add-Member -NotePropertyName "SCCM_ResourceId" -NotePropertyValue $resourceID
        $tempObject | Add-Member -NotePropertyName "SCCM_SID" -NotePropertyValue $sid
        $tempObject | Add-Member -NotePropertyName "SCCM_PSShowComputerName" -NotePropertyValue "False"
        $tempObject | Add-Member -NotePropertyName "SCCM_Dato" -NotePropertyValue $now

        $enheter += $tempObject

        $localMacs.Remove($selectedMac)

        Write-Progress -Activity "Lager SCCM-enheter..." -Status "Utført: $i av $count" -PercentComplete (($i / $count) * 100)
    }
    $enheter
}
