function Lag-TestData {
    [CmdletBinding()]
    param (
        [Parameter(Mandatory)][Int]$AntallDager
    )

    #Parse config for sql og analyser
    $config = Get-ConfigFil -pathTilFil $PSScriptRoot/configuration.ini

    $rootPath = $PSScriptRoot
    $secretMode = $config.SecretMode
    $mellomLagerSize = $config.MellomLagerSize

    $pathTilAnalyser = ""
    if($config.RelPaths -eq $true){
        $pathTilAnalyser = $rootPath + $config.PathTilAnalyser
    }else{
        $pathTilAnalyser = $config.PathTilAnalyser
    }

    $pathTilMellomLager = ""
    if($config.RelPaths -eq $true){
        $pathTilMellomLager = $rootPath + $config.pathTilMellomLager
    }else{
        $pathTilMellomLager = $config.pathTilMellomLager
    }

    #Azure
    $AzureUserName = $config.Azure_UserName
    $AzureSQLServer = $config.Azure_SQLServer
    $AzurePort = $config.Azure_Port
    $AzureDatabaseNavn = $config.Azure_databaseNavn

    $Azurepassword = ""
    if ($secretMode -eq "plain") {
        $Azurepassword = $config.Azure_password
    }elseif ($SecretMode -eq "file") {
        $Azurepassword = Get-Content $config.Azure_passwordPath | Unprotect-Passord
    }

    Write-Debug $AzureUserName
    Write-Debug $AzureSQLServer
    Write-Debug $AzureDatabaseNavn
    Write-Debug $AzurePort
    Write-Debug $Azurepassword

    #SQL
    $SQLBatchSize = $config.SQL_BatchSize


    #Generering av informasjon

    
    $ipTable = Format-IPtable -path ($PSScriptRoot + "\DHCP scopes, Domstoladministrasjonen.xlsx")
    $ipTable | Clean-Hashtable
    $macTable = New-HashTableOfMacs -count 108 -seed 10

    $macsIps = Merge-HashTablesMacsIps -macs $macTable -ips $ipTable

    $sccmNot = @()

    for ($i = 0; $i -lt 5; $i++) {
        $sccmNot += $macsIps.Keys | Get-Random
    }

    for($i = 0; $i -lt $AntallDager; $i++){
#Generer data
        
        $AntallEnheterS = Get-Random -Minimum 60 -Maximum 95

        $AntallEnheterA = Get-Random -Minimum 60 -Maximum 95

        $AntallEnheterC = Get-Random -Minimum 60 -Maximum 95

        $today = [datetime]::Now.AddDays(-$i)

        $sccmUthenting = New-SCCMFakeData -count $AntallEnheterS -macs $macsIps -now $today -disAllowed $sccmNot
        $ampUthenting = New-AMPFakeData -count $AntallEnheterA -macs $macsIps -now $today
        $cppmUthenting = New-CPPMFakeData -count $AntallEnheterC -macs $macsIps -now $today

        $nodeDataCollection = @($sccmUthenting, $ampUthenting, $cppmUthenting)

        $mergedData = Merge-NodeData -nodeData $nodeDataCollection
#Mellomlagre data
        [String]$pathpre = Get-Date -Date ($today) -Format "yyyy-MM-dd"
        $pathex = ".uthenting"
        $mergedData | ConvertTo-Json | Out-File -FilePath $pathTilMellomLager\$pathpre$pathex

        Remove-DataEldreEnn1Uke -Sti $pathTilMellomLager -LagerSize $mellomLagerSize

#Send til database
        $isSQL = Test-SqlConnection -brukernavn $AzureUserName -passord $Azurepassword -SQLServer $AzureSQLServer -port $AzurePort -DatabaseNavn $AzureDatabaseNavn
        
        If($isSQL){
            Write-Debug "Connection til database OK"
    
            Write-Verbose "Batcher enheter fra mergedData"
            $batchedEnheter = Group-SQLInnsending -udeltTing $mergedData.Keys -batchSize $SQLBatchSize
            
            Write-Debug "Starter ForEach enhetBatch in batchedEnheter"
            ForEach($enhetBatch in $batchedEnheter){
                $EnhetQuery = New-SqlQueryEnheter -Enheter $enhetBatch
                Write-Debug "Query som sendes til database: `n$enhetQuery"
    
                Write-Debug "Prøver å sende query til tabell Enheter i database"
                try {
                    Send-QueryToDatabase -Query $EnhetQuery -brukernavn $AzureUserName -passord $Azurepassword -SQLServer $AzureSQLServer -port $AzurePort -DatabaseNavn $AzureDatabaseNavn    
                }
                catch {
                    $ErrorMessage = $_.Exception.Message
                    if($ErrorMessage -like 'Exception calling "Fill" with "1" argument(s): "Violation of PRIMARY KEY constraint*'){
                        Write-Debug "Duplicate MAC i enheter, dropper"
                    }else{
                    Write-Host "Feil i innsending til tabell Enheter i database" -ForegroundColor Red
                    Write-Host $ErrorMessage -ForegroundColor Red
                    }

                }             
            }#End For each enhetbatch in batchedenheter

            Write-Verbose "Batcher enheter fra SCCMUthenting"
            $batchedSCCM = Group-SQLInnsending -udeltTing $SCCMUthenting -batchSize $SQLBatchSize

            Write-Verbose "Sender batcher inn til database"
            ForEach($SCCMbatch in $batchedSCCM){
                $SCCMQuery = New-SqlQuerySCCM -Innsending $SCCMbatch
                Write-Debug "Query som sendes tl database: `n$SCCMQuery"
                
                Write-Debug "Prøver å sende query til tabell SCCM_Uthenting i database"
                try {
                    Send-QueryToDatabase -Query $SCCMQuery -brukernavn $AzureUserName -passord $Azurepassword -SQLServer $AzureSQLServer -port $AzurePort -DatabaseNavn $AzureDatabaseNavn  
                }
                catch {
                    $ErrorMessage = $_.Exception.Message
                    Write-Host "Feil i innsending til tabell SCCM_Uthenting i database" -ForegroundColor Red
                    Write-Host $ErrorMessage -ForegroundColor Red
                }
            }#End For Each sccmbatch in bacthedsccm

            Write-Verbose "Batcher enheter fra AMPUthenting"
            $batchedAMP = Group-SQLInnsending -udeltTing $AMPUthenting -batchSize $SQLBatchSize

            Write-Verbose "Sender batcher inn til database"
            ForEach($AMPbatch in $batchedAMP){
                $AMPQuery = New-SqlQueryAMP -Innsending $AMPbatch
                Write-Debug "Query som sendes til database: `n$AMPQuery"

                Write-Debug "Prøver å sende query til tabell AMP_Uthenting i database"
                try {
                    Send-QueryToDatabase -Query $AMPQuery -brukernavn $AzureUserName -passord $Azurepassword -SQLServer $AzureSQLServer -port $AzurePort -DatabaseNavn $AzureDatabaseNavn  
                }
                catch {
                    $ErrorMessage = $_.Exception.Message
                    Write-Host "Feil i innsending til tabell AMP_Uthenting i database" -ForegroundColor Red
                    Write-Host $ErrorMessage -ForegroundColor Red
                }                 
            }#End For Each ampbatch in batchedamp

            Write-Verbose "Batcher enheter fra CPPMUthenting"
            $batchedCPPM = Group-SQLInnsending -udeltTing $CPPMUthenting -batchSize $SQLBatchSize

            Write-Verbose "Sender batcher inn til database"
            ForEach($CPPMbatch in $batchedCPPM){
                $CPPMQuery = New-SqlQueryCPPM -Innsending $CPPMbatch
                Write-Debug "Query som sendes til database: `n$CPPMQuery"

                Write-Debug "Prøver å sende query til tabell CPPM_Uthenting i database"
                try {
                    Send-QueryToDatabase -Query $CPPMQuery -brukernavn $AzureUserName -passord $Azurepassword -SQLServer $AzureSQLServer -port $AzurePort -DatabaseNavn $AzureDatabaseNavn 
                }
                catch {
                    $ErrorMessage = $_.Exception.Message
                    Write-Host "Feil i innsending til tabell CPPM_Uthenting i database" -ForegroundColor Red
                    Write-Host $ErrorMessage -ForegroundColor Red
                }                  
            }#End for each cppmbatch in batchedcppm
        }#End is SQL
    }#End For x dager


}#End Function