# Skriptet formaterer SCCM-data som blir lagt inn og returnerer en formatert tabell.
Function Formater-SCCMData{
    
    [CmdletBinding()]
    
    # Setter de parametrene som skal brukes:
    param([System.Object]$sccmUthenting)

    # Looper gjennom alle klientene
    foreach ($Klient in $sccmUthenting) {
       
    
    }
    # Lager tabellen for formatert data:
    $Formatertdata = @()

    # Endrer på navngivingen slik at alt starter med "SCCM_":
    $propertyprefix = "SCCM_"

    # Henter dagens dato med riktig format slik at hver fil blir sortert etter uthentingsdato:
    $Dato = [DateTime]::Now

    
    $IP_ARRAY = @{}
    $IP_ARRAY = Format-IPtable -path ($PSScriptRoot + '\..\DHCP scopes, Domstoladministrasjonen.xlsx')

    # Format-IPtable benytter Import-XLSX
    #$DebugPreference = "Continue"

    $count = $sccmUthenting.count
    $counter = 0

    # Looper gjennom hver klient i uthentet data:
    Foreach ($klient in $sccmUthenting){
        
        # Lager et nytt objekt for å endre på navngivningen på enhetenes properties:
        $tempobject = New-Object pscustomobject
        
        # Formaterer IP-Adresse. Deler opp IPv4 og IPv6:

        # Formater MAC-Adresse:
        $MACDeler = $Klient.MACAddresses -split ";"
        $MAC0 = $MACDeler[0]
        $tempobject | Add-Member -MemberType NoteProperty -Name SCCM_MAC -Value $MAC0

        $resterendeMACS = ""
        if($MACDeler.count -gt 1){
            for ($i = 1; $i -le $MACDeler.count; $i++){
                $resterendeMACS += $MACDeler[$i]
                if($i -lt $MACDeler.count-1){
                    $resterendeMACS += ", "
                }
            }
        }
        $tempobject | add-member -MemberType NoteProperty -Name SCCM_OtherMACs -Value $resterendeMACS

        # Looper gjennom hver property for klienten og endrer på navngivningen:
        foreach ($property in $Klient.psobject.properties.name){
            # Det kan være flere IP'er, MAC-adresser og Agenter. Her deles de opp i egne properties:
            if(-not($property -eq "MACAddresses")) {
                $tempobject | Add-Member -NotePropertyName $propertyprefix$property -NotePropertyValue $Klient.$property
            }
        }
    
        $IPs = @()
        $IPs = $klient.IPAddresses
        $IPlok = @()

        Write-Verbose "Sjekker lokasjon for ip-adresse"
        foreach ($ip in $ips) {
            $ipcomp = Format-IPLok $ip

            Write-Debug "Sjekker lokasjon for $ip"

            if($IP_ARRAY.containskey($ipcomp)){
                $IPlok += $IP_ARRAY.$ipcomp
                $DebugLok = $IP_ARRAY.$ipcomp
                Write-Debug "$ip tilhorer $DebugLok"

            }
            else{
                if($ip -like "*::*:*:*:*"){
                    $IPlok += "Unknown Local IPv6"
                    Write-Debug "$ip er en Unknown Local IPv6"
                }elseif ($ip -like "*.*.*.*") {
                    $IPlok += "Unknown IPv4"
                    Write-Debug "$ip er en Unknown IPv4"
                }elseif ($ip -like "????:????:*"){
                    $IPlok += "Unknown Public IPv6"
                    Write-Debug "$ip er en Unknown Public IPv6"
                }
            }
            
        }
        $tempobject | Add-Member -MemberType NoteProperty -Name SCCM_IPLOK -Value $IPLok

        # Lager propertyen for dato for hver klient:
        $tempobject | Add-Member -NotePropertyName $propertyprefix"Dato" -NotePropertyValue $Dato
        # Legger til hver formaterte klient inn i "FormatertData":
        $FormatertData+=$tempobject

        # Progressbar
        Write-Progress -Activity "Formaterer SCCM-klienter..." -Status "Formaterer $counter av $count" -PercentComplete (($counter / $count)*100)
        $counter ++
    }

    # Returnerer formatert tabell
    $Formatertdata
}
