# Skriptet henter data fra sccm
Function Get-SCCMKlienter{
    
    [CmdletBinding()]

    #SiteCode = "PR2"
    # Setter de parametrene som skal brukes:
    param([string]$query, [string]$SCCM_URL, [string]$SiteCode)   

    # Oppretter en sesjon mot SCCM-server:
    try{
        $sessionVar = New-PSSession -ComputerName $SCCM_URL -Name Uthenting_SCCM
    }
    catch{"Noe gikk galt ved opprettelse av sesjon"}

    # Kjører script på SCCM-server ved å benytte Invoke-Command:
    try{ 
        Invoke-Command -Session $sessionVar -ScriptBlock {

            # Feilmelding dersom scriptet ikke fungerer:
            $initParams = @{}
            $initParams.Add("ErrorAction", "Stop")

            # Importerer ConfigurationManager.psd1 modulen hvis den ikke allerede eksisterer: 
            if((Get-Module ConfigurationManager) -eq $null) {
                Import-Module "$($ENV:SMS_ADMIN_UI_PATH)\..\ConfigurationManager.psd1" @initParams 
            }

            # Kobler til site drive:
            if((Get-PSDrive -Name $using:SiteCode -PSProvider CMSite -ErrorAction SilentlyContinue) -eq $null) {
                New-PSDrive -Name $using:SiteCode -PSProvider CMSite -Root $using:SCCM_URL @initParams
            }

            # Setter lokasjon til å være site code:
            Set-Location "$($using:SiteCode):\" @initParams

        }
    }catch{"Noe gikk galt ved kobling mot sccm-databasen"}

    # Henter data fra SCCM og legger det i en variabel:
    $sccmUthenting = Invoke-Command -Session $sessionVar -ScriptBlock {Invoke-CMQuery -Name $using:query} -Verbose

    # Fjerner oppkoblingen mot SCCM-serveren som vi åpnet i starten av scriptet:
    try{
        Remove-PSSession -Name Uthenting_SCCM
    }
    catch{"Noe gikk galt ved fjerning av sesjon"}

    # Returnerer rådata fra SCCM.
    $sccmUthenting
}
