# Funksjonen tilpasser CPPM-data slik at det matcher databasen. Til slutt returneres spørringen for å sende inn data til databasen.
function New-SqlQueryCPPM {
    
    [CmdletBinding()]

    # Parameteret som hentes inn er AMP-data som skal sendes inn til databasen.
    param (
        [Parameter(Mandatory, ValueFromPipeline)][Object[]]$innsending
    )
    
    
    begin {
        # Navnet på tabellen i databasen:
        $TabellNavn = "Uthenting_CPPM"

        # Lager et tomt array som fylles med en og en formatert enhet.
        $allValues = @()
    }#End Begin
    
    process {
        Write-Verbose "Går gjennom hver CPPM-enhet og formaterer SQL-streng"
        ForEach ($e in $Innsending){
            $MAC = $e.CPPM_MAC
            $Mac_Vendor = $e.CPPM_Mac_Vendor
            $IP = $e.CPPM_IP
            $IPlok = $e.CPPM_IPlok
            $Static_IP = $e.CPPM_Is_Static_IP
            $Hostname = $e.CPPM_Hostname
            $Fingerprint = $e.CPPM_Fingerprint
            $Status = $e.CPPM_Status
            $User = $e.CPPM_User
            $Domain = $e.CPPM_Domain
            $Roles = $e.CPPM_Roles
            $SPT = $e.CPPM_Spt
            $Device_Category = $e.CPPM_Device_Category
            $Device_Family = $e.CPPM_Device_Family
            $Device_Name = $e.CPPM_Device_Name
            $Is_Conflict = $e.CPPM_Is_Conflict
            $Other_Category = $e.CPPM_Other_Category
            $Other_Family = $e.CPPM_Other_Family
            $Other_Name = $e.CPPM_Other_Name
            $Is_Online = $e.CPPM_Is_Online
            $Added_At = $e.CPPM_Added_At
            $Updated_At = $e.CPPM_Updated_at
            $Dato = $e.CPPM_dato
            
            # Viktig at rekkefølgen her stemmer med $atributter som er 5 linjer under.
            $eValues = "'$MAC', '$Mac_Vendor', '$IP', '$IPLok', '$Static_IP', '$Hostname', '$Fingerprint', '$Status', '$User', '$Domain', '$Roles', '$SPT', '$Device_Category', '$Device_Family', '$Device_Name', '$Is_Conflict', '$Other_Category', '$Other_Family', '$Other_Name', '$Is_Online', '$Added_At', '$Updated_At', '$Dato'"
            $allValues += $eValues
            Write-Debug "Enheten får følgende SQL-streng: $eValues"
        }#End ForEach $e in $Innsending
    }#End Process
    
    end {
        # $atributter må stemme med rekkefølgen i databasen.
        $atributter = "MAC, CPPM_Mac_Vendor, CPPM_IP, CPPM_IPLok, CPPM_Is_Static_IP, CPPM_Hostname, CPPM_Fingerprint, CPPM_Status, CPPM_User, CPPM_Domain, CPPM_Roles, CPPM_SPT, CPPM_Device_Category, CPPM_Device_Family, CPPM_Device_Name, CPPM_Is_Conflict, CPPM_Other_Category, CPPM_Other_Family, CPPM_Other_Name, CPPM_Is_Online, CPPM_Added_At, CPPM_Updated_At, CPPM_Dato"
        $count = 0
        $max = $allValues.Count

        # Lager et tomt array for ferdig formatert enhetsinformasjon
        $fullValue = @()

        Write-Verbose "Formaterer SQL-streng slik at det blir komma mellom values og avsluttes med semikolon"
        foreach ($v in $allValues) {
            $count += 1

            $value = "($v)"

            if($count -lt $max){
                $value += ","
            }elseif($count -eq $max){
                $value += ";"
            }

            $fullValue += $value

        }
        
        # Lager sql-spørringen for å sende inn CPPM-data til databasen.
        $Start = "INSERT INTO $TabellNavn ($atributter) VALUES $fullValue"

        # Returnerer spørringen:
        $Start
    }#End End
}