Function ConvertFrom-UnixTime($unixTime){
    [timezone]::CurrentTimeZone.ToLocalTime(([datetime]'1/1/1970').AddSeconds($unixTime))
}

Function New-RandomMac{
    [CmdletBinding()]
    param($seed = (Get-Random))
    Write-Host "seed = $seed"
    $mac = ""
    For($i=0; $i -le 11; $i++){
        Write-Host ($seed + $i)
        $char = [convert]::ToString(((Get-Random -SetSeed ($seed + $i))% 15), 16)
        $mac += $char
        if((($i % 2) -eq 1)-and($i -ne 11)){
            $mac += ":"
        }
    }
    Write-Host $mac
    $mac
}

Function New-HashTableOfMacs{
    [CmdletBinding()]
    param([int]$count=10, [int]$seed = (Get-Random))


    $macs = @{}

    For($i=1;$i-le $count;$i++){
        $mac = New-RandomMac -seed ($seed + ($i*13))
        $macs.add($mac.ToUpper(), $false)
        Write-Progress -Activity "Lager random macs" -Status "Utført: $i av $count" -PercentComplete (($i / $count) * 100)
    }
    $macs
}

Function New-RandomIP{
    [CmdletBinding()]
    param()

    $ip = ""
    $ip += "10.0."
    $ip += Get-Random -Minimum 1 -Maximum 4
    $ip += "."
    $ip += Get-Random -Minimum 25 -Maximum 250
    $ip
}

Function New-RandomDate{
    [CmdletBinding()]
    param([DateTime]$min = ([DateTime]"1/1/2018"), [DateTime]$max = ([DateTime]::Now))

    $randTicks = Get-Random -Minimum $min.Ticks -Maximum $max.Ticks
    New-Object DateTime($randTicks)
}

Function New-RandomString{
    [CmdletBinding()]
    param([int]$length = 10)

    -join ((48..57)+(65..90)+(97..122) | Get-Random -Count $length | ForEach-Object {[char]$_})
}

Function Get-AnalyseListe{
    #Funksjonen finner alle .ps1-filer som ligger i pathen, og legger navnet til disse i et array som returneres. Brukes for analyse av enheter.
    [CmdletBinding()]
    param([string]$path)

    $funcNames = Get-ChildItem $path | Where-Object -Property Name -Like "*.ps1" | Select-Object -Property Name
    $AnalyseListe = @()

    ForEach($f in $funcNames){
        $temp = $f.Name.Split(".")
        $AnalyseListe += $temp[0]
    }

    $AnalyseListe
}

Function Get-ConfigFil {
    #Funksjonen henter konfigurasjonsfilen fra pathen, og formaterer et hashtable der hvert punkt i konfig-filen inneholder verdien som er satt.
    param([string]$pathTilFil)
    

    $conf = @{}
    Get-Content $pathTilFil | ForEach-Object -Process { $k = [regex]::split($_,'='); if((($k[0].CompareTo("") -ne 0) -and (($k[0].StartsWith("[") -ne $True))) -and ($k[0].StartsWith("#") -ne $true)) { $conf.Add($k[0], $k[1]) } }
    $conf
}

function Clone-Object {
    <#
    Funksjonen kjører en deep-clone på et objekt, slik at vi ikke endrer på det originale objektet.
    Forfatter: Bruker CosmosKey på www.stackoverflow.com
    Hentet fra: https://stackoverflow.com/a/7475744
    Dato: 29.03.19, 11.06
    #>
    param($DeepCopyObject)
    $memStream = new-object IO.MemoryStream
    $formatter = new-object Runtime.Serialization.Formatters.Binary.BinaryFormatter
    $formatter.Serialize($memStream,$DeepCopyObject)
    $memStream.Position=0
    $formatter.Deserialize($memStream)
}

function Protect-Passord{
    #Funksjonen konverterer et plaintext-passord til en secure string, og returnerer denne.
    param([Parameter(Mandatory, ValueFromPipeline)][string]$passord)

    $kryptertpassord = $passord | ConvertTo-SecureString -AsPlainText -Force | ConvertFrom-SecureString
    $kryptertpassord
}

function Unprotect-Passord{
    #Funksjonen får inn en kryptert string, og prøver å dektryptere denne. Funker kun om det er samme bruker på samme maskin som skal dekryptere.
    param([Parameter(Mandatory, ValueFromPipeline)][string]$kryptertPassord)

    $SecurePassword = ConvertTo-SecureString $kryptertPassord
    $BSTR = [System.Runtime.InteropServices.Marshal]::SecureStringToBSTR($SecurePassword)
    $UnsecurePassword = [System.Runtime.InteropServices.Marshal]::PtrToStringAuto($BSTR)
    $UnsecurePassword
}

function Format-MAC {
    #Formaterer en mac-adresse som er på formen AABBCCDDEEFF til formen AA:BB:CC:DD:EE:FF
    param([Parameter(Mandatory, ValueFromPipeline)][string]$macAddr)

    $formatertMac = $macAddr.Insert(2,":").Insert(5,":").Insert(8,":").Insert(11,":").Insert(14,":").ToUpper()

    $formatertMac
}

Function IsInAllottedTime{
    #Funksjonen finner ut om et tidspunkt (nå) er innenfor to tidspunkt, for å unngå overbelastning av SCCM-server.
    param(
        [Parameter(Mandatory)][datetime]$startTime,
        [Parameter(Mandatory)][datetime]$endTime,
        [Parameter()][datetime]$Ctime = [datetime]::now
    )

    $e = $endTime.TimeOfDay
    $s = $startTime.TimeOfDay
    $c = $Ctime.TimeOfDay

    if($e -gt $s){

        Write-Debug "END $e is greater than START $s"
        if(($c -ge $s) -and ($c -le $e)){
            Write-Debug "$c is/is after $s AND $c is/is before $e"
            return $true
        }else{
            Write-Debug "$c is/is before $s or $c is/is after $e"
            return $false
        }
    }else{

        Write-Debug "END $e is not greater than START $s"
        if(-not(($c -lt $s)-and($c -gt $e))){
            Write-Debug "$c is after $s AND $c is before than $e"
            return $true
        }else{
            Write-Debug "$c is before $s OR $c is after than $e"
            return $false
        }
    }
}

# Skriptet sletter filer som er eldre enn 1 uke fra valgt sti.
Function Remove-DataEldreEnn1Uke{
    
    [CmdletBinding()]

    # Setter de parametrene som skal brukes:
    param([String]$Sti, [int]$LagerSize)

    $EldreEnn1Uke = (-($LagerSize+1))
    $DagensDato = Get-Date
    $DatetoDelete = $DagensDato.AddDays($EldreEnn1Uke)
    $GamleFiler = Get-ChildItem $Sti | Where-Object {$_.LastWriteTime -lt $DatetoDelete}

    if ($GamleFiler -eq ""){
        Write-Verbose "Fant ingen gamle filer i $Sti"
    }
    else{
        Write-Verbose "$GamleFiler skal slettes"
        $GamleFiler | Remove-Item
    }
}

#Funksjonen tar inn et hashtable, og returnerer et nytt hashtable der gammle keys nå er values, og motsatt.
Function flip-hashtable{
    param($oldhash)

    $fliphashtable = @{}

    foreach($item in $oldhash.keys){
        $fliphashtable.Add($oldhash.$item, $item)
    }
    $fliphashtable
}